import java.sql.*;

public class MovieDatabase
{
	private Connection connection;
	private PreparedStatement findByNumber, updateCategory;
	private CallableStatement findByCategory;

	public MovieDatabase(Connection connection) throws SQLException
	{
		this.connection = connection;
		findByNumber = connection.prepareStatement("SELECT * FROM Movies WHERE number = ?");
		updateCategory = connection.prepareStatement("UPDATE Movies SET category = ? WHERE number = ?");
		findByCategory = connection.prepareCall("{call SelectByCategory(?)}");
	}

	public void showByCategory(String category)
	{
		try
		{
			findByCategory.setString(1, category);

			System.out.println("Calling stored procedure SelectByCategory");
			ResultSet result = findByCategory.executeQuery();

			System.out.println("Found the following movies in " + category);
			while(result.next())
			{
				System.out.println(result.getString("title"));
			}

		}
		catch(SQLException e)
		{
		   e.printStackTrace();
		}

	}

	public void changeCategory(int number, String newCategory)
	{
		try
		{
			updateCategory.setString(1, newCategory);
			updateCategory.setInt(2, number);
			updateCategory.executeUpdate();

			System.out.println("Verifying change...");
			findByNumber.setInt(1, number);
			ResultSet results = findByNumber.executeQuery();

			if(results.next())
			{
				System.out.println("Category of " + results.getString("title") + " is " + results.getString("category"));
			}
			else
			{
				System.out.println("No movie found matching number " + number);
			}
		}
		catch(SQLException e)
		{
		   e.printStackTrace();
		}
	}

	public void addMovie(Movie movie)
	{
		System.out.println("Adding movie: " + movie.toString());
		try
		{
			Statement addMovie = connection.createStatement();
			String sql = "INSERT INTO Movies VALUES("
					+ movie.getNumber() + ", "
					+ "'" + movie.getMovieTitle() + "', "
					+ "'" + movie.getCategory() + "', "
					+ "'" + movie.getFormat() + "')";

			System.out.println("Executing statement: " + sql);
			addMovie.executeUpdate(sql);
			addMovie.close();
			System.out.println("Movie added successfully!");
		}
		catch(SQLException e)
		{
		   e.printStackTrace();
		}
	}

	public void showAllMovies()
	{
		try
		{
			Statement selectAll = connection.createStatement();
			String sql = "SELECT * FROM Movies";

			ResultSet results =	selectAll.executeQuery(sql);
			while(results.next())
			{
				int number = results.getInt(1);
				String title = results.getString("title");
				String category = results.getString(3);
				String format = results.getString(4);

				Movie movie = new Movie(number, title, category, format);
				System.out.println(movie.toString());
			}

			results.close();
			selectAll.close();
		}
		catch(SQLException e)
		{
		   e.printStackTrace();
		}
	}
}
